@@ -1,7 +1,5 @@
 #!/usr/bin/env python
-"""
-1000 Genomes - A Deep Catalog of Human Genetic Variation
-"""
+"""1000 Genomes - A Deep Catalog of Human Genetic Variation."""
 
 # We can another GATK resource since it's pretty much the same
 from example import Resource as iResource
