@@ -5,5 +5,4 @@ class GATK(FTP):
   """docstring for NCBI"""
   def __init__(self):
     super(GATK, self).__init__("ftp.broadinstitute.org",
-                               "gsapubftp-anonymous",
-                               "")
+                               "gsapubftp-anonymous", "")
